{ inputs, config, pkgs, ... }:

{
  imports = [
    (import ./modules/zsh/config.nix { inherit config pkgs; })
    (import ./modules/nvim/config.nix { inherit config pkgs; })
    (import ./modules/email/config.nix { inherit config pkgs; })
    (import ./modules/hyprland/config.nix { inherit inputs config pkgs; })
    (import ./modules/rofi/config.nix { inherit inputs config pkgs; })
  ];

  home.stateVersion = "24.11";
  targets.genericLinux.enable = true;
  nixpkgs.config.allowUnfree = true;

  home.packages = with pkgs; [
    htop
    mailcap
  ];

  home.file = {
    ".mailcap".text = "text/html; w3m -dump -o -document_charset=%{charset} %s; nametemplate=%s.html; copiousoutput";
  };

  programs.bash.enable = true;
  programs.home-manager.enable = true;
  programs.git = {
    enable = true;
    userName = "Thomas Avé";
    userEmail = "email@thomasave.be";
    aliases = {
      s = "status";
      a = "add";
    };
    extraConfig = {
        credentials.helper = "store";
        pull.rebase = false;
        push.autoSetupRemove = true;
        init.defaultBranch = "master";
        diff.noprefix = true;
        color.ui = "auto";
        core = {
            excludesfile = "~/.gitignore";
            editor = "${pkgs.neovim}/bin/nvim";
        };
    };
  };

  home.sessionVariables = {
    XDG_CONFIG_HOME = "${config.xdg.configHome}";
    XDG_CACHE_HOME = "${config.xdg.cacheHome}";
    XDG_DATA_HOME = "${config.xdg.dataHome}";
    XDG_STATE_HOME = "${config.xdg.stateHome}";

    CUDA_CACHE_PATH = "${config.xdg.cacheHome}/nv";
    DOCKER_CONFIG = "${config.xdg.configHome}/docker";
    LESSHISTFILE = "${config.xdg.cacheHome}/less/history";
    PARALLEL_HOME = "${config.xdg.configHome}/parallel";
    PYTHONSTARTUP = "${config.xdg.configHome}/python/pythonrc";
    SQLITE_HISTORY = "${config.xdg.cacheHome}/sqlite_history";
    WINEPREFIX = "${config.xdg.dataHome}/wine";
    XDG_CURRENT_DESKTOP = "GNOME";
    OPENCV_LOG_LEVEL = "ERROR";
    COLORTERM = "truecolor";
  };
}
